==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodParameter.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodParameter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2a246eaa5607679b soot_jimple_toolkits_annotation_arraycheck_MethodParameter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_soot_SootMethod$object *, jint);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_java_lang_Object$object *);
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs {
	jint	param;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodParameter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/MethodParameter.h <==
// class soot.jimple.toolkits.annotation.arraycheck.MethodParameter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2a246eaa5607679b soot_jimple_toolkits_annotation_arraycheck_MethodParameter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$_init$d745e6fbf60e11d4(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_soot_SootMethod$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vmethods	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_refs	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs {
	jint	param;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_MethodParameter;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_MethodParameter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_MethodParameter$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_MethodParameter_H_ */
